@@ -1,5 +1,5 @@
 use super::coordinate::Coordinate;
-use crate::error::{GraphBlasError, GraphBlasErrorType, LogicError, LogicErrorType};
+use crate::error::{SparseLinearAlgebraError, GraphBlasError, GraphBlasErrorType, LogicError, LogicErrorType};
 use crate::util::ElementIndex;
 use crate::value_types::value_type::ValueType;
 
@@ -73,10 +73,12 @@ impl<T: ValueType + Clone + Copy> MatrixElementList<T> {
         row_index: Vec<ElementIndex>,
         column_index: Vec<ElementIndex>,
         value: Vec<T>,
-    ) -> Result<Self, GraphBlasError> {
+    ) -> Result<Self, SparseLinearAlgebraError> {
         #[cfg(debug_assertions)]
         if (row_index.len() != column_index.len()) && (column_index.len() == value.len()) {
-            return Err(GraphBlasError::new(GraphBlasErrorType::DimensionMismatch, format!("Length of vectors must be equal: row_index.len() = {}, column_index.len() = {}, value.len() = {}", row_index.len(), column_index.len(), value.len())));
+            return Err(GraphBlasError::new(GraphBlasErrorType::DimensionMismatch, 
+                format!("Length of vectors must be equal: row_index.len() = {}, column_index.len() = {}, value.len() = {}", 
+                row_index.len(), column_index.len(), value.len())).into());
         }
         Ok(Self {
             row_index,
@@ -111,7 +113,7 @@ impl<T: ValueType + Clone + Copy> MatrixElementList<T> {
         &self.row_index.as_slice()
     }
 
-    pub(crate) fn row_index(&self, index: ElementIndex) -> Result<&ElementIndex, LogicError> {
+    pub(crate) fn row_index(&self, index: ElementIndex) -> Result<&ElementIndex, SparseLinearAlgebraError> {
         #[cfg(debug_assertions)]
         if index > self.length() {
             return Err(LogicError::new(
@@ -122,12 +124,12 @@ impl<T: ValueType + Clone + Copy> MatrixElementList<T> {
                     self.length()
                 ),
                 None,
-            ));
+            ).into());
         }
         Ok(&self.row_index[index])
     }
 
-    pub(crate) fn column_index(&self, index: ElementIndex) -> Result<&ElementIndex, LogicError> {
+    pub(crate) fn column_index(&self, index: ElementIndex) -> Result<&ElementIndex, SparseLinearAlgebraError> {
         #[cfg(debug_assertions)]
         if index > self.length() {
             return Err(LogicError::new(
@@ -138,7 +140,7 @@ impl<T: ValueType + Clone + Copy> MatrixElementList<T> {
                     self.length()
                 ),
                 None,
-            ));
+            ).into());
         }
         Ok(&self.column_index[index])
     }
