@@ -2,5 +2,5 @@ mod value_type;
 mod value_type_convertable_to_boolean;
 
 pub(crate) use value_type::RegisteredCustomValueType;
-pub use value_type::{BuiltInValueType, CustomValueType, ValueType};
+pub use value_type::{BuiltInValueType, ValueType};
 pub use value_type_convertable_to_boolean::AsBoolean;
